You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ph...@apache.org on 2011/10/13 13:15:26 UTC

svn commit: r1182784 - in /subversion/trunk/subversion: include/private/svn_mutex.h libsvn_subr/svn_mutex.c

Author: philip
Date: Thu Oct 13 11:15:26 2011
New Revision: 1182784

URL: http://svn.apache.org/viewvc?rev=1182784&view=rev
Log:
* subversion/include/private/svn_mutex.h
  (svn_mutex__init): Update comment to reflect r1182340, rename parameter.

* subversion/libsvn_subr/svn_mutex.c
  (): Update header comment.
  (svn_mutex__init): Rename parameter.

Modified:
    subversion/trunk/subversion/include/private/svn_mutex.h
    subversion/trunk/subversion/libsvn_subr/svn_mutex.c

Modified: subversion/trunk/subversion/include/private/svn_mutex.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/private/svn_mutex.h?rev=1182784&r1=1182783&r2=1182784&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_subr/svn_mutex.c (original)
+++ subversion/trunk/subversion/libsvn_subr/svn_mutex.c Thu Oct 13 11:15:26 2011
@@ -1,5 +1,5 @@
 /*
- * svn_mutex.c: in-memory caching for Subversion
+ * svn_mutex.c: routines for mutual exclusion.
  *
  * ====================================================================
  *    Licensed to the Apache Software Foundation (ASF) under one
@@ -27,7 +27,7 @@
 svn_error_t *
 svn_mutex__init(svn_mutex__t **mutex_p, 
                 svn_boolean_t enable_mutex, 
-                apr_pool_t *pool)
+                apr_pool_t *result_pool)
 {
 #if APR_HAS_THREADS
   *mutex_p = NULL;
@@ -37,7 +37,7 @@ svn_mutex__init(svn_mutex__t **mutex_p, 
       apr_status_t status =
           apr_thread_mutex_create(&apr_mutex,
                                   APR_THREAD_MUTEX_DEFAULT,
-                                  pool);
+                                  result_pool);
       if (status)
         return svn_error_wrap_apr(status, _("Can't create mutex"));
--- subversion/trunk/subversion/include/private/svn_mutex.h (original)
+++ subversion/trunk/subversion/include/private/svn_mutex.h Thu Oct 13 11:15:26 2011
@@ -56,10 +56,9 @@ typedef void svn_mutex__t;
 #endif
 
 /** Initialize the @a *mutex. If @a enable_mutex is TRUE, the mutex will
  * actually be created with a lifetime defined by @a pool. Otherwise, the
  * pointer will be set to @c NULL and @ref svn_mutex__lock as well as
  * @ref svn_mutex__unlock will be no-ops. The same happens at the end 
  * of the pool lifetime as part of the pool cleanup.
  * 
  * If @a enable_mutex is set but threading is not supported by APR, this 
  * function returns an @c APR_ENOTIMPL error.
@@ -67,7 +66,7 @@ typedef void svn_mutex__t;
 svn_error_t *
 svn_mutex__init(svn_mutex__t **mutex,
                 svn_boolean_t enable_mutex,
-                apr_pool_t *pool);
+                apr_pool_t *result_pool);
 
 /** Acquire the @a mutex, if that has been enabled in @ref svn_mutex__init.
  * Make sure to call @ref svn_mutex__unlock some time later in the same 
@@ -56,10 +56,9 @@ typedef void svn_mutex__t;
 
 /** Initialize the @a *mutex. If @a enable_mutex is TRUE, the mutex will
- * actually be created with a lifetime defined by @a pool. Otherwise, the
- * pointer will be set to @c NULL and @ref svn_mutex__lock as well as
- * @ref svn_mutex__unlock will be no-ops. The same happens at the end 
- * of the pool lifetime as part of the pool cleanup.
+ * actually be created with a lifetime defined by @a result_pool. Otherwise,
+ * the pointer will be set to @c NULL and @ref svn_mutex__lock as well as
+ * @ref svn_mutex__unlock will be no-ops.
  * 
  * If @a enable_mutex is set but threading is not supported by APR, this 

Modified: subversion/trunk/subversion/libsvn_subr/svn_mutex.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_subr/svn_mutex.c?rev=1182784&r1=1182783&r2=1182784&view=diff
==============================================================================